==> clustering_google_maps-0.0.2.tar.gz: README.md <==
# Clustering for Flutter Google Maps 

[![pub package](https://img.shields.io/pub/v/clustering_google_maps.svg)](https://pub.dartlang.org/packages/clustering_google_maps)

A Flutter package that recreate clustering technique in a [Google Maps](https://developers.google.com/maps/) widget.

<div style="text-align: center"><table><tr>
  <td style="text-align: center">
  <a href="https://github.com/giandifra/clustering_google_maps/blob/master/example.gif">
    <img src="https://github.com/giandifra/clustering_google_maps/blob/master/example.gif" width="200"/></a>
</td>
</tr></table></div>

## Developers Preview Status
The package recreate the CLUSTERING technique in a Google Maps. 
It's work with data recordered in a dababase SQLite. I use [sqflite](https://pub.dartlang.org/packages/sqflite)

## Usage

To use this package, add `clustering_google_maps` as a [dependency in your pubspec.yaml file](https://flutter.io/platform-plugins/).

For a better performance, at every zoom variation on the map, the package performs
a specific query on the SQLite database. This solution is better than loading all
points in memory (in a list) and then aggregating points on the map. 

## Getting Started

For the package to work properly, you must have the data of the points saved in a SQLite database.
Latitude, longitude and the string of geohash. These three parameters are necessary for correct operation.
If you have not saved the [GEOHASH](https://pub.dartlang.org/packages/geohash), I suggest you install [GEOHASH](https://pub.dartlang.org/packages/geohash)
plugin and save the value of Geohash in the points table of db.

### Future Implementations

- To further improve performance I am creating a way to perform sql queries only on the latlng bounding box displayed on the map. 
- I will insert custom marker with number of points. But for now [Google Maps](https://developers.google.com/maps/) widget does not allow
  custom widget from dart but only static Bitmap

### Quick Example

```dart
import 'package:example/app_db.dart';
import 'package:example/fake_point.dart';
import 'package:flutter/material.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:sqflite/sqflite.dart';
import 'package:clustering_google_maps/clustering_google_maps.dart';

class HomeScreen extends StatefulWidget {
  HomeScreen({Key key}) : super(key: key);

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  ClusteringHelper clusteringHelper;
  final CameraPosition initialCameraPosition =
      CameraPosition(target: LatLng(0.000000, 0.000000), zoom: 0.0);

  Set<Marker> markers = Set();

  void _onMapCreated(GoogleMapController mapController) async {
    print("onMapCreated");
    final Database database = await AppDatabase.get().getDb();
    clusteringHelper = ClusteringHelper.forDB(
      database: database,
      mapController: mapController,
      dbGeohashColumn: FakePoint.dbGeohash,
      dbLatColumn: FakePoint.dbLat,
      dbLongColumn: FakePoint.dbLong,
      dbTable: FakePoint.tblFakePoints,
      updateMarkers: updateMarkers,
    );
  }

  updateMarkers(Set<Marker> markers) {
    setState(() {
      this.markers = markers;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Clustering Example"),
      ),
      body: GoogleMap(
        onMapCreated: _onMapCreated,
        trackCameraPosition: true,
        initialCameraPosition: initialCameraPosition,
        markers: markers,
      ),
    );
  }
}
```

See the `example` directory for a complete sample app.

==> clustering_google_maps-0.0.4.tar.gz: README.md <==
# Clustering for Flutter Google Maps 

[![pub package](https://img.shields.io/pub/v/clustering_google_maps.svg)](https://pub.dartlang.org/packages/clustering_google_maps)

A Flutter package that recreate clustering technique in a [Google Maps](https://developers.google.com/maps/) widget.

<div style="text-align: center"><table><tr>
  <td style="text-align: center">
  <a href="https://github.com/giandifra/clustering_google_maps/blob/master/example.gif">
    <img src="https://github.com/giandifra/clustering_google_maps/blob/master/example.gif" width="200"/></a>
</td>
</tr></table></div>

## Developers Preview Status
The package recreate the CLUSTERING technique in a Google Maps. 
It's work with data recordered in a dababase SQLite. I use [sqflite](https://pub.dartlang.org/packages/sqflite)

## Usage

To use this package, add `clustering_google_maps` as a [dependency in your pubspec.yaml file](https://flutter.io/platform-plugins/).

For a better performance, at every zoom variation on the map, the package performs
a specific query on the SQLite database. This solution is better than loading all
points in memory (in a list) and then aggregating points on the map. 

## Getting Started

For the package to work properly, you must have the data of the points saved in a SQLite database.
Latitude, longitude and the string of geohash. These three parameters are necessary for correct operation.
If you have not saved the [GEOHASH](https://pub.dartlang.org/packages/geohash), I suggest you install [GEOHASH](https://pub.dartlang.org/packages/geohash)
plugin and save the value of Geohash in the points table of db.

### Future Implementations

- To further improve performance I am creating a way to perform sql queries only on the latlng bounding box displayed on the map. 
- I will insert custom marker with number of points. But for now [Google Maps](https://developers.google.com/maps/) widget does not allow
  custom widget from dart but only static Bitmap

### Quick Example

```dart
import 'package:example/app_db.dart';
import 'package:example/fake_point.dart';
import 'package:flutter/material.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:sqflite/sqflite.dart';
import 'package:clustering_google_maps/clustering_google_maps.dart';

class HomeScreen extends StatefulWidget {
  HomeScreen({Key key}) : super(key: key);

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  ClusteringHelper clusteringHelper;
  final CameraPosition initialCameraPosition =
      CameraPosition(target: LatLng(0.000000, 0.000000), zoom: 0.0);

  Set<Marker> markers = Set();

  void _onMapCreated(GoogleMapController mapController) async {
    print("onMapCreated");
    clusteringHelper.database = await AppDatabase.get().getDb();
    clusteringHelper.updateMap();
  }

  updateMarkers(Set<Marker> markers) {
    setState(() {
      this.markers = markers;
    });
  }

  @override
  void initState() {
    initClustering();
    super.initState();
  }

  initClustering() {
    clusteringHelper = ClusteringHelper.forDB(
      dbGeohashColumn: FakePoint.dbGeohash,
      dbLatColumn: FakePoint.dbLat,
      dbLongColumn: FakePoint.dbLong,
      dbTable: FakePoint.tblFakePoints,
      updateMarkers: updateMarkers,
    );
  }

  @override
  Widget build(BuildContext context) {
    print("build");
    return Scaffold(
      appBar: AppBar(
        title: Text("Clustering Example"),
      ),
      body: GoogleMap(
        onMapCreated: _onMapCreated,
        initialCameraPosition: initialCameraPosition,
        markers: markers,
        onCameraMove: clusteringHelper.onCameraMove,
        onCameraIdle: clusteringHelper.onMapIdle,
      ),
      floatingActionButton: FloatingActionButton(
          child: Icon(Icons.content_cut),
          onPressed: () {
            clusteringHelper.whereClause = "WHERE ${FakePoint.dbLat} > 42.6";
            clusteringHelper.updateMap();
          }),
    );
  }
}
```

See the `example` directory for a complete sample app.
